@@ -1,5 +1,5 @@
-#RDEX#\dontrun{
-require(psd)
+\dontrun{#REX
+library(psd)
 ##
 ## Taper constraint procedures
 ##
@@ -7,14 +7,16 @@ data(magnet)
 X <- magnet$clean
 ##
 ## spectrum, then riedsid
-kopt <- riedsid(PSD <- psdcore(X, ntaper=10, refresh=TRUE))
+PSD <- psdcore(X, ntaper=10, refresh=TRUE)
+#
+kopt <- riedsid(PSD)
 kopt.loess  <- riedsid(PSD, c.method="loess.smooth")
 #
-plot(kopt, log="y", ylim =c(.1, 3e2))
-lines(kopt.loess, log="y", col="green")
+plot(kopt, log.y=TRUE, ylim =c(.1, 3e2))
+lines(kopt.loess)
 ##
 ##
 ## To compare all the methods at once:
 demo("ctap")
 ##
-#RDEX#}
+}#REX
