@@ -1,5 +1,5 @@
-#RDEX#\dontrun{
-require(psd)
+\dontrun{#REX
+library(psd)
 ##
 ## Normalization
 ##
@@ -29,4 +29,4 @@ plot(PSD, add=TRUE, col="red", log="dB")
 mean(pgram$spec)*max(pgram$freq)
 mean(PSD$spec)*max(PSD$freq)
 #
-#RDEX#}
+}#REX
