@@ -1,5 +1,5 @@
-#RDEX#\dontrun{
-require(psd)
+\dontrun{#REX
+library(psd)
 ##
 ## Multitaper PSD estimation
 ##
@@ -11,8 +11,8 @@ plot(psdcore(X))
 #
 # use more tapers, compare to stats::spectrum, and clear 
 # env data from the previous calculation
-psdcore(X, ntapers=10, plotpsd=TRUE, refresh=TRUE)
+psdcore(X, ntaper=10, plot=TRUE, refresh=TRUE)
 #
 # change the sampling frequency to 20
-psdcore(X, 20, 10, plotpsd=TRUE, refresh=TRUE) 
-#RDEX#}
+psdcore(X, 20, 10, plot=TRUE, refresh=TRUE) 
+}#REX
