@@ -1,16 +1,18 @@
-#RDEX#\dontrun{
-require(psd)
+\dontrun{#REX
+library(psd)
+library(RColorBrewer)
 ##
 ## Adaptive multitaper PSD estimation
 ## (portions extracted from overview vignette)
+## for the Project MAGNET dataset
 ##
-require(RColorBrewer)
-##
-## adaptive estimation for the Project MAGNET dataset
+
 data(magnet)
+
 # adaptive psd estimation (turn off diagnostic plot)
 PSDr <- pspectrum(Xr <- magnet$raw, plot=FALSE)
 PSDc <- pspectrum(Xc <- magnet$clean, plot=FALSE)
+
 # plot them on the same scale
 plot(PSDc, log="dB", main="Raw and Clean Project MAGNET power spectral density",
      lwd=3, ci.col=NA, ylim=c(0,32), yaxs="i")
@@ -71,4 +73,4 @@ invisible(lapply(rev(seqcols), FUN=function(mcol, niter=numit, Frq=Freqs, Dat=St
   polygon(c(x,rev(x),x[1]),y,border="black",col=icol)
 }
 )) # end of invisible lapply
-#RDEX#}
+}#REX
